@@ -19,6 +19,7 @@ pub enum Op {
     ADCS = Operation_ARM64_ADCS as u32,
     ADD = Operation_ARM64_ADD as u32,
     ADDG = Operation_ARM64_ADDG as u32,
+    ADDHA = Operation_ARM64_ADDHA as u32,
     ADDHN = Operation_ARM64_ADDHN as u32,
     ADDHN2 = Operation_ARM64_ADDHN2 as u32,
     ADDHNB = Operation_ARM64_ADDHNB as u32,
@@ -27,6 +28,7 @@ pub enum Op {
     ADDPL = Operation_ARM64_ADDPL as u32,
     ADDS = Operation_ARM64_ADDS as u32,
     ADDV = Operation_ARM64_ADDV as u32,
+    ADDVA = Operation_ARM64_ADDVA as u32,
     ADDVL = Operation_ARM64_ADDVL as u32,
     ADR = Operation_ARM64_ADR as u32,
     ADRP = Operation_ARM64_ADRP as u32,
@@ -73,6 +75,8 @@ pub enum Op {
     BFMLALB = Operation_ARM64_BFMLALB as u32,
     BFMLALT = Operation_ARM64_BFMLALT as u32,
     BFMMLA = Operation_ARM64_BFMMLA as u32,
+    BFMOPA = Operation_ARM64_BFMOPA as u32,
+    BFMOPS = Operation_ARM64_BFMOPS as u32,
     BFXIL = Operation_ARM64_BFXIL as u32,
     BGRP = Operation_ARM64_BGRP as u32,
     BIC = Operation_ARM64_BIC as u32,
@@ -308,6 +312,8 @@ pub enum Op {
     FMLSLB = Operation_ARM64_FMLSLB as u32,
     FMLSLT = Operation_ARM64_FMLSLT as u32,
     FMMLA = Operation_ARM64_FMMLA as u32,
+    FMOPA = Operation_ARM64_FMOPA as u32,
+    FMOPS = Operation_ARM64_FMOPS as u32,
     FMOV = Operation_ARM64_FMOV as u32,
     FMSB = Operation_ARM64_FMSB as u32,
     FMSUB = Operation_ARM64_FMSUB as u32,
@@ -367,6 +373,7 @@ pub enum Op {
     LD1B = Operation_ARM64_LD1B as u32,
     LD1D = Operation_ARM64_LD1D as u32,
     LD1H = Operation_ARM64_LD1H as u32,
+    LD1Q = Operation_ARM64_LD1Q as u32,
     LD1R = Operation_ARM64_LD1R as u32,
     LD1RB = Operation_ARM64_LD1RB as u32,
     LD1RD = Operation_ARM64_LD1RD as u32,
@@ -584,6 +591,7 @@ pub enum Op {
     MLS = Operation_ARM64_MLS as u32,
     MNEG = Operation_ARM64_MNEG as u32,
     MOV = Operation_ARM64_MOV as u32,
+    MOVA = Operation_ARM64_MOVA as u32,
     MOVI = Operation_ARM64_MOVI as u32,
     MOVK = Operation_ARM64_MOVK as u32,
     MOVN = Operation_ARM64_MOVN as u32,
@@ -668,6 +676,7 @@ pub enum Op {
     REV32 = Operation_ARM64_REV32 as u32,
     REV64 = Operation_ARM64_REV64 as u32,
     REVB = Operation_ARM64_REVB as u32,
+    REVD = Operation_ARM64_REVD as u32,
     REVH = Operation_ARM64_REVH as u32,
     REVW = Operation_ARM64_REVW as u32,
     RMIF = Operation_ARM64_RMIF as u32,
@@ -712,6 +721,7 @@ pub enum Op {
     SBFIZ = Operation_ARM64_SBFIZ as u32,
     SBFM = Operation_ARM64_SBFM as u32,
     SBFX = Operation_ARM64_SBFX as u32,
+    SCLAMP = Operation_ARM64_SCLAMP as u32,
     SCVTF = Operation_ARM64_SCVTF as u32,
     SDIV = Operation_ARM64_SDIV as u32,
     SDIVR = Operation_ARM64_SDIVR as u32,
@@ -774,7 +784,11 @@ pub enum Op {
     SMLSLT = Operation_ARM64_SMLSLT as u32,
     SMMLA = Operation_ARM64_SMMLA as u32,
     SMNEGL = Operation_ARM64_SMNEGL as u32,
+    SMOPA = Operation_ARM64_SMOPA as u32,
+    SMOPS = Operation_ARM64_SMOPS as u32,
     SMOV = Operation_ARM64_SMOV as u32,
+    SMSTART = Operation_ARM64_SMSTART as u32,
+    SMSTOP = Operation_ARM64_SMSTOP as u32,
     SMSUBL = Operation_ARM64_SMSUBL as u32,
     SMULH = Operation_ARM64_SMULH as u32,
     SMULL = Operation_ARM64_SMULL as u32,
@@ -874,6 +888,7 @@ pub enum Op {
     ST1B = Operation_ARM64_ST1B as u32,
     ST1D = Operation_ARM64_ST1D as u32,
     ST1H = Operation_ARM64_ST1H as u32,
+    ST1Q = Operation_ARM64_ST1Q as u32,
     ST1W = Operation_ARM64_ST1W as u32,
     ST2 = Operation_ARM64_ST2 as u32,
     ST2B = Operation_ARM64_ST2B as u32,
@@ -991,6 +1006,8 @@ pub enum Op {
     SUBR = Operation_ARM64_SUBR as u32,
     SUBS = Operation_ARM64_SUBS as u32,
     SUDOT = Operation_ARM64_SUDOT as u32,
+    SUMOPA = Operation_ARM64_SUMOPA as u32,
+    SUMOPS = Operation_ARM64_SUMOPS as u32,
     SUNPKHI = Operation_ARM64_SUNPKHI as u32,
     SUNPKLO = Operation_ARM64_SUNPKLO as u32,
     SUQADD = Operation_ARM64_SUQADD as u32,
@@ -1052,6 +1069,7 @@ pub enum Op {
     UBFIZ = Operation_ARM64_UBFIZ as u32,
     UBFM = Operation_ARM64_UBFM as u32,
     UBFX = Operation_ARM64_UBFX as u32,
+    UCLAMP = Operation_ARM64_UCLAMP as u32,
     UCVTF = Operation_ARM64_UCVTF as u32,
     UDF = Operation_ARM64_UDF as u32,
     UDIV = Operation_ARM64_UDIV as u32,
@@ -1077,6 +1095,8 @@ pub enum Op {
     UMLSLT = Operation_ARM64_UMLSLT as u32,
     UMMLA = Operation_ARM64_UMMLA as u32,
     UMNEGL = Operation_ARM64_UMNEGL as u32,
+    UMOPA = Operation_ARM64_UMOPA as u32,
+    UMOPS = Operation_ARM64_UMOPS as u32,
     UMOV = Operation_ARM64_UMOV as u32,
     UMSUBL = Operation_ARM64_UMSUBL as u32,
     UMULH = Operation_ARM64_UMULH as u32,
@@ -1128,6 +1148,8 @@ pub enum Op {
     USHLLT = Operation_ARM64_USHLLT as u32,
     USHR = Operation_ARM64_USHR as u32,
     USMMLA = Operation_ARM64_USMMLA as u32,
+    USMOPA = Operation_ARM64_USMOPA as u32,
+    USMOPS = Operation_ARM64_USMOPS as u32,
     USQADD = Operation_ARM64_USQADD as u32,
     USRA = Operation_ARM64_USRA as u32,
     USUBL = Operation_ARM64_USUBL as u32,
@@ -1170,12 +1192,13 @@ pub enum Op {
     XTN = Operation_ARM64_XTN as u32,
     XTN2 = Operation_ARM64_XTN2 as u32,
     YIELD = Operation_ARM64_YIELD as u32,
+    ZERO = Operation_ARM64_ZERO as u32,
     ZIP1 = Operation_ARM64_ZIP1 as u32,
     ZIP2 = Operation_ARM64_ZIP2 as u32,
 }
 
 // this is a guard to try to detect if new instructions get added
-const_assert_eq!(Operation_ARM64_ZIP2, 1160);
+const_assert_eq!(Operation_ARM64_ZIP2, 1183);
 
 impl Op {
     /// Get the operation name
