@@ -11,6 +11,37 @@ use crate::Reg;
 use crate::Shift;
 use crate::SysReg;
 
+/// A slice indicator
+#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
+pub enum SliceIndicator {
+    Horizontal,
+    Vertical,
+}
+
+#[allow(non_upper_case_globals)]
+#[doc(hidden)]
+impl TryFrom<&bad64_sys::InstructionOperand> for SliceIndicator {
+    type Error = ();
+
+    fn try_from(oo: &bad64_sys::InstructionOperand) -> Result<Self, Self::Error> {
+        match oo.slice {
+            SliceIndicator_SLICE_NONE => Err(()),
+            SliceIndicator_SLICE_HORIZONTAL => Ok(Self::Horizontal),
+            SliceIndicator_SLICE_VERTICAL=> Ok(Self::Vertical),
+            _ => Err(()),
+        }
+    }
+}
+
+impl fmt::Display for SliceIndicator {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match *self {
+            Self::Horizontal => write!(f, "H"),
+            Self::Vertical => write!(f, "V"),
+        }
+    }
+}
+
 /// An instruction immediate
 #[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
 pub enum Imm {
@@ -87,6 +118,22 @@ pub enum Operand {
         shift: Option<Shift>,
         arrspec: Option<ArrSpec>,
     },
+    SmeTile {
+        tile: u16,
+        slice: Option<SliceIndicator>,
+        arrspec: Option<ArrSpec>,
+        reg: Option<Reg>,
+        imm: Imm,
+    },
+    AccumArray {
+        reg: Reg,
+        imm: Imm,
+    },
+    IndexedElement {
+        regs: [Reg; 2],
+        arrspec: Option<ArrSpec>,
+        imm: Imm,
+    },
     Label(Imm),
     ImplSpec {
         o0: u8,
@@ -184,6 +231,25 @@ impl TryFrom<&bad64_sys::InstructionOperand> for Operand {
                 shift: Shift::try_from(oo).ok(),
                 arrspec: ArrSpec::try_from(oo).ok(),
             }),
+            OperandClass::SME_TILE => Ok(Self::SmeTile {
+                tile: oo.tile,
+                slice: SliceIndicator::try_from(oo).ok(),
+                arrspec: ArrSpec::try_from(oo).ok(),
+                reg: Reg::from_u32(oo.reg[0] as u32),
+                imm: Imm::from(oo),
+            }),
+            OperandClass::INDEXED_ELEMENT => Ok(Self::IndexedElement {
+                regs: [
+                    Reg::from_u32(oo.reg[0] as u32).unwrap(),
+                    Reg::from_u32(oo.reg[1] as u32).unwrap(),
+                ],
+                arrspec: ArrSpec::try_from(oo).ok(),
+                imm: Imm::from(oo),
+            }),
+            OperandClass::ACCUM_ARRAY => Ok(Self::AccumArray {
+                reg: Reg::from_u32(oo.reg[0] as u32).unwrap(),
+                imm: Imm::from(oo)
+            }),
             OperandClass::LABEL => Ok(Self::Label(Imm::from(oo))),
             OperandClass::IMPLEMENTATION_SPECIFIC => Ok(Self::ImplSpec {
                 o0: oo.implspec[0],
@@ -298,6 +364,33 @@ impl fmt::Display for Operand {
                 }
                 write!(f, "]")
             }
+            Self::SmeTile { tile, slice, arrspec, reg, imm } => {
+                write!(f, "Z{}", tile)?;
+
+                if let Some(slice) = slice {
+                    write!(f, "{}", slice)?;
+                }
+
+                if let Some(arrspec) = arrspec {
+                    write!(f, "{}", arrspec.suffix_truncated())?;
+                }
+
+                match (reg, arrspec) {
+                    (Some(reg), Some(ArrSpec::Full(_))) => write!(f, "[{}]", reg),
+                    (Some(reg), _) => write!(f, "[{}, {}]", reg, imm),
+                    _ => write!(f, ""),
+                }
+            },
+            Self::AccumArray { reg, imm } => write!(f, "ZA[{}, #{}]", reg, imm),
+            Self::IndexedElement { regs, arrspec, imm } => {
+                write_full_reg(f, regs[0], arrspec)?;
+                write!(f, "[{}", regs[1])?;
+
+                if !matches!(imm, Imm::Signed(0) | Imm::Unsigned(0)) {
+                    write!(f, "{{, #{}}}", imm)?;
+                }
+                write!(f, "]")
+            }
             Self::Label(imm) => write!(f, "{}", imm),
             Self::ImplSpec { o0, o1, cm, cn, o2 } => {
                 write!(f, "s{}_{}_c{}_c{}_{}", o0, o1, cm, cn, o2)
